ChartStyle class

Constructors

ChartStyle()

Properties

bottomPadding ↔ double
getter/setter pair
candleLineWidth ↔ double
getter/setter pair
candleWidth ↔ double
getter/setter pair
childPadding ↔ double
getter/setter pair
dateTimeFormat ↔ List<String>?
getter/setter pair
gridColumns ↔ int
getter/setter pair
gridRows ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hCrossWidth ↔ double
getter/setter pair
macdWidth ↔ double
getter/setter pair
nowPriceLineLength ↔ double
getter/setter pair
nowPriceLineSpan ↔ double
getter/setter pair
nowPriceLineWidth ↔ double
getter/setter pair
pointWidth ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topPadding ↔ double
getter/setter pair
vCrossWidth ↔ double
getter/setter pair
volWidth ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited